@@ -293,8 +293,8 @@ void Tray::contextMenuAboutToShow (TDEPopupMenu* menu)
 		else if ( devices == 1 )
 		{
 			newConnAction = actionCollection ()->action ("new_connection");
-			TQT_BASE_OBJECT_NAME::disconnect( newConnAction, TQT_SIGNAL(activated()) );
-			TQT_BASE_OBJECT_NAME::connect( newConnAction, TQT_SIGNAL(activated()), d->trayComponents[0], TQT_SLOT(newConnection()));
+			TQObject::disconnect( newConnAction, TQT_SIGNAL(activated()) );
+			TQObject::connect( newConnAction, TQT_SIGNAL(activated()), d->trayComponents[0], TQT_SLOT(newConnection()));
 		}
 		if (newConnAction) {
 			newConnAction->plug(menu);
@@ -585,7 +585,7 @@ void Tray::updateDeviceTrays()
 
 void Tray::mousePressEvent( TQMouseEvent *e )
 {
-	if ( !TQT_TQRECT_OBJECT(rect()).contains( e->pos() ) ) {
+	if ( !rect().contains( e->pos() ) ) {
 		return;
 	}
 	switch ( e->button() ) {
